@@ -67,7 +67,7 @@ tar_network <- function(
   outdated = TRUE,
   reporter = targets::tar_config_get("reporter_outdated"),
   callr_function = callr::r,
-  callr_arguments = targets::callr_args_default(callr_function, reporter),
+  callr_arguments = targets::tar_callr_args_default(callr_function, reporter),
   envir = parent.frame(),
   script = targets::tar_config_get("script"),
   store = targets::tar_config_get("store")
